"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getEndpointFromConfig = void 0;
const getEndpointFromConfig = async (serviceId) => undefined;
exports.getEndpointFromConfig = getEndpointFromConfig;
